@@ -3,4 +3,6 @@ from metta.processors.sink_processor import SinkProcessor
 from metta.processors.source_processor import SourceProcessor
 
 from metta.common.config import Config, SourceConfig, SinkConfig
-from metta.types.topic_pb2 import TopicMessage
\ No newline at end of file
+from metta.common import time_utils
+from metta.types.topic_pb2 import TopicMessage
+from metta.topics.topics import Message, NewMessage
\ No newline at end of file
